# Generated by Django 3.1.1 on 2020-10-08 22:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apistats', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='apistat',
            name='ip',
            field=models.GenericIPAddressField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='query',
            field=models.CharField(blank=True, max_length=2000),
        ),
    ]
