# Generated by Django 3.1.1 on 2020-10-09 12:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('apistats', '0004_auto_20201009_1151'),
    ]

    operations = [
        migrations.AddField(
            model_name='apistat',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='delay',
            field=models.IntegerField(verbose_name='delay (ms) between request and response'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='domain',
            field=models.CharField(db_index=True, max_length=50, verbose_name='Application domain'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='ip',
            field=models.GenericIPAddressField(blank=True, null=True, verbose_name='Client IP address'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='method',
            field=models.CharField(max_length=10, verbose_name='call method'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='path',
            field=models.CharField(db_index=True, max_length=255, verbose_name='Application path'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='query',
            field=models.CharField(blank=True, max_length=2000, verbose_name='Query parameters'),
        ),
        migrations.AlterField(
            model_name='apistat',
            name='record_time',
            field=models.DateTimeField(auto_now=True, primary_key=True, serialize=False, verbose_name='Recorded at'),
        ),
    ]
