# Generated by Django 3.1.1 on 2020-10-08 22:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apistats', '0002_auto_20201008_2203'),
    ]

    operations = [
        migrations.AddField(
            model_name='apistat',
            name='domain',
            field=models.CharField(db_index=True, default='test', max_length=50),
            preserve_default=False,
        ),
    ]
