# Generated by Django 3.1.1 on 2020-10-09 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apistats', '0003_apistat_domain'),
    ]

    operations = [
        migrations.AddField(
            model_name='apistat',
            name='delay',
            field=models.IntegerField(default=0, verbose_name='delay between request and response'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='apistat',
            name='status',
            field=models.IntegerField(default=200, verbose_name='Response status code'),
            preserve_default=False,
        ),
    ]
